@@ -339,7 +339,7 @@ class RTCLocalUserObserverInner(ctypes.Structure):
         #note: for video, one user can publish multiple video tracks, so the identifier is the remote_video_track_handle,
         # its diff to audiotrack
         self.local_user.set_remote_video_map(remote_video_track_handle, remote_video_track)
-        track_info = video_track_info.contents.to_track_info()
+        track_info = video_track_info.contents._convert_to_video_track_info()
         self.local_user_observer.on_user_video_track_subscribed(self.local_user, user_id_str, track_info, remote_video_track)
 
     def _on_user_video_track_state_changed(self, local_user_handle, user_id, remote_video_track_handle, state, reason, elapsed):
